Package 'SARA'

Title: This is a package for the AFSC Groundfish stock assessment results
Description:
Authors: Ianelli Jim [aut, cre]
Maintainer: Jim Ianelli- NOAA Federal <[email protected]>
License: GPL-2
Version: 1.0
Built: 2026-07-15 06:01:21 UTC
Source: https://github.com/afsc-assessments/sara

Help Index


Process SARA report files into dataframes and save to a spreadsheet

Description

Depends on having files in the rawdata subdirectory Will crash if file format incorrect

Usage

SARA()

Value

update from last year's files


Actual function that reads in existing Tier 3 datafiles (results) in data subdirectory, then appends the results from the rawdata subdirectory

Description

Draft

Usage

SARA_readwrite(dbg = FALSE)

Value

update from last year's files


Actual function that reads in existing Tier 5 datafiles in data subdirectory, then appends the results from the rawdata subdirectory

Description

Draft

Usage

SARA_readwrite_form()

Details

SARA report files into dataframes

Value

update from last year's files